@@ -8,13 +8,15 @@
     covr.exclude_end = rex::rex("#", any_spaces, "nocov", any_spaces, "end"),
     covr.flags = c(CFLAGS = "-O0 -coverage",
                  CXXFLAGS = "-O0 -coverage",
+                 CXX1XFLAGS = "-O0 -coverage",
+
                  FFLAGS = "-O0 -coverage",
                  FCFLAGS = "-O0 -coverage",
 
                  # LDFLAGS is ignored on windows and visa versa
                  LDFLAGS = if (!is_windows()) "-coverage" else NULL,
-                 SHLIB_LIBADD = if (is_windows()) "-coverage" else NULL
-  ))
+                 SHLIB_LIBADD = if (is_windows()) "-coverage" else NULL)
+  )
   toset <- !(names(op_covr) %in% names(op))
   if (any(toset)) options(op_covr[toset])
 
